@@ -17,6 +17,11 @@ class LatestPipelineProductModel(Base):
 
     id = Column(Integer, primary_key=True)
     product_name = Column(String(191), nullable=False, index=True)
+    intervention_id = Column(
+        Integer,
+        ForeignKey('interventions.id'),
+        nullable=False,
+    )
     news_id = Column(
         Integer,
         ForeignKey('newswires.id'),
@@ -31,4 +36,4 @@ class LatestPipelineProductModel(Base):
         onupdate=lambda: datetime.utcnow(),
     )
 
-    __table_args__ = (UniqueConstraint("product_name"),)
+    __table_args__ = (UniqueConstraint("product_name", "intervention_id"),)
